@@ -16,7 +16,7 @@
 # along with "sc8pr".  If not, see <http://www.gnu.org/licenses/>.
 
 
-version = 2, 2, 0
+version = 2, 2, "1-dev"
 print("sc8pr {}.{}.{}: https://dmaccarthy.github.io/sc8pr".format(*version))
 
 import sys, struct, zlib, io
@@ -1170,7 +1170,7 @@ class Sketch(Canvas):
     @cursor.setter
     def cursor(self, c):
         if c is True: c = pygame.cursors.arrow
-        elif c is False: c = (8,8), (5,4), (0,0,0,0,0,0,0,0), (0,0,0,0,0,0,0,0)
+        elif c is False: c = (8,8), (5,4), 8*(0,), 8*(0,)
         pygame.mouse.set_cursor(*c)
 
     def save(self, fn=None):
